#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_PROD_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_PROD_HPP_INCLUDED

#include <boost/simd/reduction/include/functions/simd/prod.hpp>

#endif
